Class: UnitOpenapiRubySdk::CreateIndividualThreadApplicationAttributes
- Inherits:
-
Object
- Object
- UnitOpenapiRubySdk::CreateIndividualThreadApplicationAttributes
- Defined in:
- lib/unit_openapi_ruby_sdk/models/create_individual_thread_application_attributes.rb
Defined Under Namespace
Classes: EnumAttributeValidator
Instance Attribute Summary collapse
-
#account_purpose ⇒ Object
Returns the value of attribute account_purpose.
-
#account_purpose_detail ⇒ Object
Returns the value of attribute account_purpose_detail.
-
#address ⇒ Object
Returns the value of attribute address.
-
#banks ⇒ Object
Returns the value of attribute banks.
-
#date_of_birth ⇒ Object
Returns the value of attribute date_of_birth.
-
#device_fingerprints ⇒ Object
Returns the value of attribute device_fingerprints.
-
#email ⇒ Object
Returns the value of attribute email.
-
#evaluation_params ⇒ Object
Returns the value of attribute evaluation_params.
-
#full_name ⇒ Object
Returns the value of attribute full_name.
-
#idempotency_key ⇒ Object
Returns the value of attribute idempotency_key.
-
#ip ⇒ Object
Returns the value of attribute ip.
-
#jwt_subject ⇒ Object
Returns the value of attribute jwt_subject.
-
#nationality ⇒ Object
Returns the value of attribute nationality.
-
#passport ⇒ Object
Returns the value of attribute passport.
-
#phone ⇒ Object
Returns the value of attribute phone.
-
#profession ⇒ Object
Returns the value of attribute profession.
-
#source_of_funds ⇒ Object
Returns the value of attribute source_of_funds.
-
#ssn ⇒ Object
Returns the value of attribute ssn.
-
#tags ⇒ Object
Returns the value of attribute tags.
-
#transaction_volume ⇒ Object
Returns the value of attribute transaction_volume.
-
#transaction_volume_description ⇒ Object
Returns the value of attribute transaction_volume_description.
Class Method Summary collapse
-
._deserialize(type, value) ⇒ Object
Deserializes the data based on type.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
-
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ CreateIndividualThreadApplicationAttributes
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility).
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Constructor Details
#initialize(attributes = {}) ⇒ CreateIndividualThreadApplicationAttributes
Initializes the object
152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 |
# File 'lib/unit_openapi_ruby_sdk/models/create_individual_thread_application_attributes.rb', line 152 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `UnitOpenapiRubySdk::CreateIndividualThreadApplicationAttributes` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| if (!self.class.attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `UnitOpenapiRubySdk::CreateIndividualThreadApplicationAttributes`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'ssn') self.ssn = attributes[:'ssn'] end if attributes.key?(:'passport') self.passport = attributes[:'passport'] end if attributes.key?(:'nationality') self.nationality = attributes[:'nationality'] end if attributes.key?(:'full_name') self.full_name = attributes[:'full_name'] else self.full_name = nil end if attributes.key?(:'date_of_birth') self.date_of_birth = attributes[:'date_of_birth'] else self.date_of_birth = nil end if attributes.key?(:'address') self.address = attributes[:'address'] else self.address = nil end if attributes.key?(:'phone') self.phone = attributes[:'phone'] else self.phone = nil end if attributes.key?(:'email') self.email = attributes[:'email'] else self.email = nil end if attributes.key?(:'evaluation_params') self.evaluation_params = attributes[:'evaluation_params'] end if attributes.key?(:'ip') self.ip = attributes[:'ip'] end if attributes.key?(:'tags') if (value = attributes[:'tags']).is_a?(Hash) self. = value end end if attributes.key?(:'idempotency_key') self.idempotency_key = attributes[:'idempotency_key'] end if attributes.key?(:'device_fingerprints') if (value = attributes[:'device_fingerprints']).is_a?(Array) self.device_fingerprints = value end end if attributes.key?(:'jwt_subject') self.jwt_subject = attributes[:'jwt_subject'] end if attributes.key?(:'banks') if (value = attributes[:'banks']).is_a?(Array) self.banks = value end end if attributes.key?(:'account_purpose') self.account_purpose = attributes[:'account_purpose'] else self.account_purpose = nil end if attributes.key?(:'account_purpose_detail') self.account_purpose_detail = attributes[:'account_purpose_detail'] end if attributes.key?(:'source_of_funds') self.source_of_funds = attributes[:'source_of_funds'] else self.source_of_funds = nil end if attributes.key?(:'transaction_volume') self.transaction_volume = attributes[:'transaction_volume'] else self.transaction_volume = nil end if attributes.key?(:'transaction_volume_description') self.transaction_volume_description = attributes[:'transaction_volume_description'] end if attributes.key?(:'profession') self.profession = attributes[:'profession'] else self.profession = nil end end |
Instance Attribute Details
#account_purpose ⇒ Object
Returns the value of attribute account_purpose.
48 49 50 |
# File 'lib/unit_openapi_ruby_sdk/models/create_individual_thread_application_attributes.rb', line 48 def account_purpose @account_purpose end |
#account_purpose_detail ⇒ Object
Returns the value of attribute account_purpose_detail.
50 51 52 |
# File 'lib/unit_openapi_ruby_sdk/models/create_individual_thread_application_attributes.rb', line 50 def account_purpose_detail @account_purpose_detail end |
#address ⇒ Object
Returns the value of attribute address.
28 29 30 |
# File 'lib/unit_openapi_ruby_sdk/models/create_individual_thread_application_attributes.rb', line 28 def address @address end |
#banks ⇒ Object
Returns the value of attribute banks.
46 47 48 |
# File 'lib/unit_openapi_ruby_sdk/models/create_individual_thread_application_attributes.rb', line 46 def banks @banks end |
#date_of_birth ⇒ Object
Returns the value of attribute date_of_birth.
26 27 28 |
# File 'lib/unit_openapi_ruby_sdk/models/create_individual_thread_application_attributes.rb', line 26 def date_of_birth @date_of_birth end |
#device_fingerprints ⇒ Object
Returns the value of attribute device_fingerprints.
42 43 44 |
# File 'lib/unit_openapi_ruby_sdk/models/create_individual_thread_application_attributes.rb', line 42 def device_fingerprints @device_fingerprints end |
#email ⇒ Object
Returns the value of attribute email.
32 33 34 |
# File 'lib/unit_openapi_ruby_sdk/models/create_individual_thread_application_attributes.rb', line 32 def email @email end |
#evaluation_params ⇒ Object
Returns the value of attribute evaluation_params.
34 35 36 |
# File 'lib/unit_openapi_ruby_sdk/models/create_individual_thread_application_attributes.rb', line 34 def evaluation_params @evaluation_params end |
#full_name ⇒ Object
Returns the value of attribute full_name.
24 25 26 |
# File 'lib/unit_openapi_ruby_sdk/models/create_individual_thread_application_attributes.rb', line 24 def full_name @full_name end |
#idempotency_key ⇒ Object
Returns the value of attribute idempotency_key.
40 41 42 |
# File 'lib/unit_openapi_ruby_sdk/models/create_individual_thread_application_attributes.rb', line 40 def idempotency_key @idempotency_key end |
#ip ⇒ Object
Returns the value of attribute ip.
36 37 38 |
# File 'lib/unit_openapi_ruby_sdk/models/create_individual_thread_application_attributes.rb', line 36 def ip @ip end |
#jwt_subject ⇒ Object
Returns the value of attribute jwt_subject.
44 45 46 |
# File 'lib/unit_openapi_ruby_sdk/models/create_individual_thread_application_attributes.rb', line 44 def jwt_subject @jwt_subject end |
#nationality ⇒ Object
Returns the value of attribute nationality.
22 23 24 |
# File 'lib/unit_openapi_ruby_sdk/models/create_individual_thread_application_attributes.rb', line 22 def nationality @nationality end |
#passport ⇒ Object
Returns the value of attribute passport.
20 21 22 |
# File 'lib/unit_openapi_ruby_sdk/models/create_individual_thread_application_attributes.rb', line 20 def passport @passport end |
#phone ⇒ Object
Returns the value of attribute phone.
30 31 32 |
# File 'lib/unit_openapi_ruby_sdk/models/create_individual_thread_application_attributes.rb', line 30 def phone @phone end |
#profession ⇒ Object
Returns the value of attribute profession.
58 59 60 |
# File 'lib/unit_openapi_ruby_sdk/models/create_individual_thread_application_attributes.rb', line 58 def profession @profession end |
#source_of_funds ⇒ Object
Returns the value of attribute source_of_funds.
52 53 54 |
# File 'lib/unit_openapi_ruby_sdk/models/create_individual_thread_application_attributes.rb', line 52 def source_of_funds @source_of_funds end |
#ssn ⇒ Object
Returns the value of attribute ssn.
18 19 20 |
# File 'lib/unit_openapi_ruby_sdk/models/create_individual_thread_application_attributes.rb', line 18 def ssn @ssn end |
#tags ⇒ Object
Returns the value of attribute tags.
38 39 40 |
# File 'lib/unit_openapi_ruby_sdk/models/create_individual_thread_application_attributes.rb', line 38 def @tags end |
#transaction_volume ⇒ Object
Returns the value of attribute transaction_volume.
54 55 56 |
# File 'lib/unit_openapi_ruby_sdk/models/create_individual_thread_application_attributes.rb', line 54 def transaction_volume @transaction_volume end |
#transaction_volume_description ⇒ Object
Returns the value of attribute transaction_volume_description.
56 57 58 |
# File 'lib/unit_openapi_ruby_sdk/models/create_individual_thread_application_attributes.rb', line 56 def transaction_volume_description @transaction_volume_description end |
Class Method Details
._deserialize(type, value) ⇒ Object
Deserializes the data based on type
505 506 507 508 509 510 511 512 513 514 515 516 517 518 519 520 521 522 523 524 525 526 527 528 529 530 531 532 533 534 535 536 537 538 539 540 541 542 |
# File 'lib/unit_openapi_ruby_sdk/models/create_individual_thread_application_attributes.rb', line 505 def self._deserialize(type, value) case type.to_sym when :Time Time.parse(value) when :Date Date.parse(value) when :String value.to_s when :Integer value.to_i when :Float value.to_f when :Boolean if value.to_s =~ /\A(true|t|yes|y|1)\z/i true else false end when :Object # generic object (usually a Hash), return directly value when /\AArray<(?<inner_type>.+)>\z/ inner_type = Regexp.last_match[:inner_type] value.map { |v| _deserialize(inner_type, v) } when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/ k_type = Regexp.last_match[:k_type] v_type = Regexp.last_match[:v_type] {}.tap do |hash| value.each do |k, v| hash[_deserialize(k_type, k)] = _deserialize(v_type, v) end end else # model # models (e.g. Pet) or oneOf klass = UnitOpenapiRubySdk.const_get(type) klass.respond_to?(:openapi_any_of) || klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value) end end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
110 111 112 |
# File 'lib/unit_openapi_ruby_sdk/models/create_individual_thread_application_attributes.rb', line 110 def self.acceptable_attributes attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 |
# File 'lib/unit_openapi_ruby_sdk/models/create_individual_thread_application_attributes.rb', line 83 def self.attribute_map { :'ssn' => :'ssn', :'passport' => :'passport', :'nationality' => :'nationality', :'full_name' => :'fullName', :'date_of_birth' => :'dateOfBirth', :'address' => :'address', :'phone' => :'phone', :'email' => :'email', :'evaluation_params' => :'evaluationParams', :'ip' => :'ip', :'tags' => :'tags', :'idempotency_key' => :'idempotencyKey', :'device_fingerprints' => :'deviceFingerprints', :'jwt_subject' => :'jwtSubject', :'banks' => :'banks', :'account_purpose' => :'accountPurpose', :'account_purpose_detail' => :'accountPurposeDetail', :'source_of_funds' => :'sourceOfFunds', :'transaction_volume' => :'transactionVolume', :'transaction_volume_description' => :'transactionVolumeDescription', :'profession' => :'profession' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
481 482 483 484 485 486 487 488 489 490 491 492 493 494 495 496 497 498 499 |
# File 'lib/unit_openapi_ruby_sdk/models/create_individual_thread_application_attributes.rb', line 481 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
142 143 144 145 146 147 148 |
# File 'lib/unit_openapi_ruby_sdk/models/create_individual_thread_application_attributes.rb', line 142 def self.openapi_nullable Set.new([ :'device_fingerprints', :'jwt_subject', :'banks', ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 |
# File 'lib/unit_openapi_ruby_sdk/models/create_individual_thread_application_attributes.rb', line 115 def self.openapi_types { :'ssn' => :'String', :'passport' => :'String', :'nationality' => :'String', :'full_name' => :'FullName', :'date_of_birth' => :'Date', :'address' => :'Address', :'phone' => :'Phone', :'email' => :'String', :'evaluation_params' => :'EvaluationParams', :'ip' => :'String', :'tags' => :'Hash<String, String>', :'idempotency_key' => :'String', :'device_fingerprints' => :'Array<DeviceFingerprint>', :'jwt_subject' => :'String', :'banks' => :'Array<String>', :'account_purpose' => :'ThreadIndividualAccountPurpose', :'account_purpose_detail' => :'String', :'source_of_funds' => :'ThreadIndividualSourceOfFunds', :'transaction_volume' => :'ThreadIndividualTransactionVolume', :'transaction_volume_description' => :'String', :'profession' => :'ThreadIndividualProfession' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
440 441 442 443 444 445 446 447 448 449 450 451 452 453 454 455 456 457 458 459 460 461 462 463 464 |
# File 'lib/unit_openapi_ruby_sdk/models/create_individual_thread_application_attributes.rb', line 440 def ==(o) return true if self.equal?(o) self.class == o.class && ssn == o.ssn && passport == o.passport && nationality == o.nationality && full_name == o.full_name && date_of_birth == o.date_of_birth && address == o.address && phone == o.phone && email == o.email && evaluation_params == o.evaluation_params && ip == o.ip && == o. && idempotency_key == o.idempotency_key && device_fingerprints == o.device_fingerprints && jwt_subject == o.jwt_subject && banks == o.banks && account_purpose == o.account_purpose && account_purpose_detail == o.account_purpose_detail && source_of_funds == o.source_of_funds && transaction_volume == o.transaction_volume && transaction_volume_description == o.transaction_volume_description && profession == o.profession end |
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value
576 577 578 579 580 581 582 583 584 585 586 587 588 |
# File 'lib/unit_openapi_ruby_sdk/models/create_individual_thread_application_attributes.rb', line 576 def _to_hash(value) if value.is_a?(Array) value.compact.map { |v| _to_hash(v) } elsif value.is_a?(Hash) {}.tap do |hash| value.each { |k, v| hash[k] = _to_hash(v) } end elsif value.respond_to? :to_hash value.to_hash else value end end |
#eql?(o) ⇒ Boolean
468 469 470 |
# File 'lib/unit_openapi_ruby_sdk/models/create_individual_thread_application_attributes.rb', line 468 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
474 475 476 |
# File 'lib/unit_openapi_ruby_sdk/models/create_individual_thread_application_attributes.rb', line 474 def hash [ssn, passport, nationality, full_name, date_of_birth, address, phone, email, evaluation_params, ip, , idempotency_key, device_fingerprints, jwt_subject, banks, account_purpose, account_purpose_detail, source_of_funds, transaction_volume, transaction_volume_description, profession].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 292 293 294 295 296 297 298 299 300 301 302 303 304 305 306 307 308 309 310 311 312 313 314 315 316 317 318 319 320 321 322 323 324 325 326 327 328 329 330 331 332 333 334 335 336 337 338 339 340 341 342 |
# File 'lib/unit_openapi_ruby_sdk/models/create_individual_thread_application_attributes.rb', line 276 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new pattern = Regexp.new(/^\d{9}$/) if !@ssn.nil? && @ssn !~ pattern invalid_properties.push("invalid value for \"ssn\", must conform to the pattern #{pattern}.") end pattern = Regexp.new(/^(A(D|E|F|G|I|L|M|N|O|R|S|T|Q|U|W|X|Z)|B(A|B|D|E|F|G|H|I|J|L|M|N|O|Q|R|S|T|V|W|Y|Z)|C(A|C|D|F|G|H|I|K|L|M|N|O|R|U|V|W|X|Y|Z)|D(E|J|K|M|O|Z)|E(C|E|G|H|R|S|T)|F(I|J|K|M|O|R)|G(A|B|D|E|F|G|H|I|L|M|N|P|Q|R|S|T|U|W|Y)|H(K|M|N|R|T|U)|I(D|E|Q|L|M|N|O|R|S|T)|J(E|M|O|P)|K(E|G|H|I|M|N|P|R|W|Y|Z)|L(A|B|C|I|K|R|S|T|U|V|Y)|M(A|C|D|E|F|G|H|K|L|M|N|O|Q|P|R|S|T|U|V|W|X|Y|Z)|N(A|C|E|F|G|I|L|O|P|R|U|Z)|OM|P(A|E|F|G|H|K|L|M|N|R|S|T|W|Y)|QA|R(E|O|S|U|W)|S(A|B|C|D|E|G|H|I|J|K|L|M|N|O|R|T|V|X|Y|Z)|T(C|D|F|G|H|J|K|L|M|N|O|R|T|V|W|Z)|U(A|G|M|S|Y|Z)|V(A|C|E|G|I|N|U)|W(F|S)|XK|Y(E|T)|Z(A|M|W))$/) if !@nationality.nil? && @nationality !~ pattern invalid_properties.push("invalid value for \"nationality\", must conform to the pattern #{pattern}.") end if @full_name.nil? invalid_properties.push('invalid value for "full_name", full_name cannot be nil.') end if @date_of_birth.nil? invalid_properties.push('invalid value for "date_of_birth", date_of_birth cannot be nil.') end if @address.nil? invalid_properties.push('invalid value for "address", address cannot be nil.') end if @phone.nil? invalid_properties.push('invalid value for "phone", phone cannot be nil.') end if @email.nil? invalid_properties.push('invalid value for "email", email cannot be nil.') end if !@tags.nil? && @tags.length > 15 invalid_properties.push('invalid value for "tags", number of items must be less than or equal to 15.') end if !@idempotency_key.nil? && @idempotency_key.to_s.length > 255 invalid_properties.push('invalid value for "idempotency_key", the character length must be smaller than or equal to 255.') end if !@idempotency_key.nil? && @idempotency_key.to_s.length < 1 invalid_properties.push('invalid value for "idempotency_key", the character length must be great than or equal to 1.') end if !@device_fingerprints.nil? && @device_fingerprints.length > 1 invalid_properties.push('invalid value for "device_fingerprints", number of items must be less than or equal to 1.') end if @account_purpose.nil? invalid_properties.push('invalid value for "account_purpose", account_purpose cannot be nil.') end if @source_of_funds.nil? invalid_properties.push('invalid value for "source_of_funds", source_of_funds cannot be nil.') end if @transaction_volume.nil? invalid_properties.push('invalid value for "transaction_volume", transaction_volume cannot be nil.') end if @profession.nil? invalid_properties.push('invalid value for "profession", profession cannot be nil.') end invalid_properties end |
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility)
552 553 554 |
# File 'lib/unit_openapi_ruby_sdk/models/create_individual_thread_application_attributes.rb', line 552 def to_body to_hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
558 559 560 561 562 563 564 565 566 567 568 569 570 |
# File 'lib/unit_openapi_ruby_sdk/models/create_individual_thread_application_attributes.rb', line 558 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
546 547 548 |
# File 'lib/unit_openapi_ruby_sdk/models/create_individual_thread_application_attributes.rb', line 546 def to_s to_hash.to_s end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
346 347 348 349 350 351 352 353 354 355 356 357 358 359 360 361 362 363 364 |
# File 'lib/unit_openapi_ruby_sdk/models/create_individual_thread_application_attributes.rb', line 346 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if !@ssn.nil? && @ssn !~ Regexp.new(/^\d{9}$/) return false if !@nationality.nil? && @nationality !~ Regexp.new(/^(A(D|E|F|G|I|L|M|N|O|R|S|T|Q|U|W|X|Z)|B(A|B|D|E|F|G|H|I|J|L|M|N|O|Q|R|S|T|V|W|Y|Z)|C(A|C|D|F|G|H|I|K|L|M|N|O|R|U|V|W|X|Y|Z)|D(E|J|K|M|O|Z)|E(C|E|G|H|R|S|T)|F(I|J|K|M|O|R)|G(A|B|D|E|F|G|H|I|L|M|N|P|Q|R|S|T|U|W|Y)|H(K|M|N|R|T|U)|I(D|E|Q|L|M|N|O|R|S|T)|J(E|M|O|P)|K(E|G|H|I|M|N|P|R|W|Y|Z)|L(A|B|C|I|K|R|S|T|U|V|Y)|M(A|C|D|E|F|G|H|K|L|M|N|O|Q|P|R|S|T|U|V|W|X|Y|Z)|N(A|C|E|F|G|I|L|O|P|R|U|Z)|OM|P(A|E|F|G|H|K|L|M|N|R|S|T|W|Y)|QA|R(E|O|S|U|W)|S(A|B|C|D|E|G|H|I|J|K|L|M|N|O|R|T|V|X|Y|Z)|T(C|D|F|G|H|J|K|L|M|N|O|R|T|V|W|Z)|U(A|G|M|S|Y|Z)|V(A|C|E|G|I|N|U)|W(F|S)|XK|Y(E|T)|Z(A|M|W))$/) return false if @full_name.nil? return false if @date_of_birth.nil? return false if @address.nil? return false if @phone.nil? return false if @email.nil? return false if !@tags.nil? && @tags.length > 15 return false if !@idempotency_key.nil? && @idempotency_key.to_s.length > 255 return false if !@idempotency_key.nil? && @idempotency_key.to_s.length < 1 return false if !@device_fingerprints.nil? && @device_fingerprints.length > 1 return false if @account_purpose.nil? return false if @source_of_funds.nil? return false if @transaction_volume.nil? return false if @profession.nil? true end |