Class: UnitOpenapiRubySdk::CreateSoleProprietorThreadApplicationAttributes

Inherits:
Object
  • Object
show all
Defined in:
lib/unit_openapi_ruby_sdk/models/create_sole_proprietor_thread_application_attributes.rb

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ CreateSoleProprietorThreadApplicationAttributes

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
266
267
268
269
270
271
272
273
274
275
276
277
278
279
280
281
282
283
284
285
286
287
288
289
290
291
292
293
294
295
296
297
298
299
300
301
302
303
304
305
306
307
308
309
310
311
312
313
314
315
316
317
318
319
320
321
322
323
324
325
326
327
328
329
330
331
332
333
334
335
336
337
338
339
340
341
342
343
344
345
346
347
348
349
350
351
352
353
354
355
356
357
358
359
360
361
362
363
364
365
# File 'lib/unit_openapi_ruby_sdk/models/create_sole_proprietor_thread_application_attributes.rb', line 195

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `UnitOpenapiRubySdk::CreateSoleProprietorThreadApplicationAttributes` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!self.class.attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `UnitOpenapiRubySdk::CreateSoleProprietorThreadApplicationAttributes`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'ssn')
    self.ssn = attributes[:'ssn']
  end

  if attributes.key?(:'passport')
    self.passport = attributes[:'passport']
  end

  if attributes.key?(:'nationality')
    self.nationality = attributes[:'nationality']
  end

  if attributes.key?(:'full_name')
    self.full_name = attributes[:'full_name']
  else
    self.full_name = nil
  end

  if attributes.key?(:'date_of_birth')
    self.date_of_birth = attributes[:'date_of_birth']
  else
    self.date_of_birth = nil
  end

  if attributes.key?(:'address')
    self.address = attributes[:'address']
  else
    self.address = nil
  end

  if attributes.key?(:'phone')
    self.phone = attributes[:'phone']
  else
    self.phone = nil
  end

  if attributes.key?(:'email')
    self.email = attributes[:'email']
  else
    self.email = nil
  end

  if attributes.key?(:'sole_proprietorship')
    self.sole_proprietorship = attributes[:'sole_proprietorship']
  else
    self.sole_proprietorship = true
  end

  if attributes.key?(:'ein')
    self.ein = attributes[:'ein']
  end

  if attributes.key?(:'dba')
    self.dba = attributes[:'dba']
  end

  if attributes.key?(:'evaluation_params')
    self.evaluation_params = attributes[:'evaluation_params']
  end

  if attributes.key?(:'website')
    self.website = attributes[:'website']
  end

  if attributes.key?(:'ip')
    self.ip = attributes[:'ip']
  end

  if attributes.key?(:'tags')
    if (value = attributes[:'tags']).is_a?(Hash)
      self.tags = value
    end
  end

  if attributes.key?(:'idempotency_key')
    self.idempotency_key = attributes[:'idempotency_key']
  end

  if attributes.key?(:'device_fingerprints')
    if (value = attributes[:'device_fingerprints']).is_a?(Array)
      self.device_fingerprints = value
    end
  end

  if attributes.key?(:'jwt_subject')
    self.jwt_subject = attributes[:'jwt_subject']
  end

  if attributes.key?(:'banks')
    if (value = attributes[:'banks']).is_a?(Array)
      self.banks = value
    end
  end

  if attributes.key?(:'source_of_funds')
    self.source_of_funds = attributes[:'source_of_funds']
  else
    self.source_of_funds = nil
  end

  if attributes.key?(:'source_of_funds_description')
    self.source_of_funds_description = attributes[:'source_of_funds_description']
  end

  if attributes.key?(:'business_industry')
    self.business_industry = attributes[:'business_industry']
  end

  if attributes.key?(:'is_incorporated')
    self.is_incorporated = attributes[:'is_incorporated']
  else
    self.is_incorporated = false
  end

  if attributes.key?(:'state_of_incorporation')
    self.state_of_incorporation = attributes[:'state_of_incorporation']
  end

  if attributes.key?(:'year_of_incorporation')
    self.year_of_incorporation = attributes[:'year_of_incorporation']
  end

  if attributes.key?(:'countries_of_operation')
    if (value = attributes[:'countries_of_operation']).is_a?(Array)
      self.countries_of_operation = value
    end
  end

  if attributes.key?(:'us_nexus')
    if (value = attributes[:'us_nexus']).is_a?(Array)
      self.us_nexus = value
    end
  end

  if attributes.key?(:'transaction_volume')
    self.transaction_volume = attributes[:'transaction_volume']
  else
    self.transaction_volume = nil
  end

  if attributes.key?(:'transaction_volume_description')
    self.transaction_volume_description = attributes[:'transaction_volume_description']
  end

  if attributes.key?(:'account_purpose')
    self. = attributes[:'account_purpose']
  else
    self. = nil
  end

  if attributes.key?(:'account_purpose_detail')
    self. = attributes[:'account_purpose_detail']
  end

  if attributes.key?(:'business_description')
    self.business_description = attributes[:'business_description']
  end
end

Instance Attribute Details

#account_purposeObject

Returns the value of attribute account_purpose.



76
77
78
# File 'lib/unit_openapi_ruby_sdk/models/create_sole_proprietor_thread_application_attributes.rb', line 76

def 
  @account_purpose
end

#account_purpose_detailObject

Returns the value of attribute account_purpose_detail.



78
79
80
# File 'lib/unit_openapi_ruby_sdk/models/create_sole_proprietor_thread_application_attributes.rb', line 78

def 
  @account_purpose_detail
end

#addressObject

Returns the value of attribute address.



28
29
30
# File 'lib/unit_openapi_ruby_sdk/models/create_sole_proprietor_thread_application_attributes.rb', line 28

def address
  @address
end

#banksObject

Returns the value of attribute banks.



54
55
56
# File 'lib/unit_openapi_ruby_sdk/models/create_sole_proprietor_thread_application_attributes.rb', line 54

def banks
  @banks
end

#business_descriptionObject

Returns the value of attribute business_description.



80
81
82
# File 'lib/unit_openapi_ruby_sdk/models/create_sole_proprietor_thread_application_attributes.rb', line 80

def business_description
  @business_description
end

#business_industryObject

Returns the value of attribute business_industry.



60
61
62
# File 'lib/unit_openapi_ruby_sdk/models/create_sole_proprietor_thread_application_attributes.rb', line 60

def business_industry
  @business_industry
end

#countries_of_operationObject

Returns the value of attribute countries_of_operation.



68
69
70
# File 'lib/unit_openapi_ruby_sdk/models/create_sole_proprietor_thread_application_attributes.rb', line 68

def countries_of_operation
  @countries_of_operation
end

#date_of_birthObject

Returns the value of attribute date_of_birth.



26
27
28
# File 'lib/unit_openapi_ruby_sdk/models/create_sole_proprietor_thread_application_attributes.rb', line 26

def date_of_birth
  @date_of_birth
end

#dbaObject

Returns the value of attribute dba.



38
39
40
# File 'lib/unit_openapi_ruby_sdk/models/create_sole_proprietor_thread_application_attributes.rb', line 38

def dba
  @dba
end

#device_fingerprintsObject

Returns the value of attribute device_fingerprints.



50
51
52
# File 'lib/unit_openapi_ruby_sdk/models/create_sole_proprietor_thread_application_attributes.rb', line 50

def device_fingerprints
  @device_fingerprints
end

#einObject

Returns the value of attribute ein.



36
37
38
# File 'lib/unit_openapi_ruby_sdk/models/create_sole_proprietor_thread_application_attributes.rb', line 36

def ein
  @ein
end

#emailObject

Returns the value of attribute email.



32
33
34
# File 'lib/unit_openapi_ruby_sdk/models/create_sole_proprietor_thread_application_attributes.rb', line 32

def email
  @email
end

#evaluation_paramsObject

Returns the value of attribute evaluation_params.



40
41
42
# File 'lib/unit_openapi_ruby_sdk/models/create_sole_proprietor_thread_application_attributes.rb', line 40

def evaluation_params
  @evaluation_params
end

#full_nameObject

Returns the value of attribute full_name.



24
25
26
# File 'lib/unit_openapi_ruby_sdk/models/create_sole_proprietor_thread_application_attributes.rb', line 24

def full_name
  @full_name
end

#idempotency_keyObject

Returns the value of attribute idempotency_key.



48
49
50
# File 'lib/unit_openapi_ruby_sdk/models/create_sole_proprietor_thread_application_attributes.rb', line 48

def idempotency_key
  @idempotency_key
end

#ipObject

Returns the value of attribute ip.



44
45
46
# File 'lib/unit_openapi_ruby_sdk/models/create_sole_proprietor_thread_application_attributes.rb', line 44

def ip
  @ip
end

#is_incorporatedObject

Returns the value of attribute is_incorporated.



62
63
64
# File 'lib/unit_openapi_ruby_sdk/models/create_sole_proprietor_thread_application_attributes.rb', line 62

def is_incorporated
  @is_incorporated
end

#jwt_subjectObject

Returns the value of attribute jwt_subject.



52
53
54
# File 'lib/unit_openapi_ruby_sdk/models/create_sole_proprietor_thread_application_attributes.rb', line 52

def jwt_subject
  @jwt_subject
end

#nationalityObject

Returns the value of attribute nationality.



22
23
24
# File 'lib/unit_openapi_ruby_sdk/models/create_sole_proprietor_thread_application_attributes.rb', line 22

def nationality
  @nationality
end

#passportObject

Returns the value of attribute passport.



20
21
22
# File 'lib/unit_openapi_ruby_sdk/models/create_sole_proprietor_thread_application_attributes.rb', line 20

def passport
  @passport
end

#phoneObject

Returns the value of attribute phone.



30
31
32
# File 'lib/unit_openapi_ruby_sdk/models/create_sole_proprietor_thread_application_attributes.rb', line 30

def phone
  @phone
end

#sole_proprietorshipObject

Returns the value of attribute sole_proprietorship.



34
35
36
# File 'lib/unit_openapi_ruby_sdk/models/create_sole_proprietor_thread_application_attributes.rb', line 34

def sole_proprietorship
  @sole_proprietorship
end

#source_of_fundsObject

Returns the value of attribute source_of_funds.



56
57
58
# File 'lib/unit_openapi_ruby_sdk/models/create_sole_proprietor_thread_application_attributes.rb', line 56

def source_of_funds
  @source_of_funds
end

#source_of_funds_descriptionObject

Returns the value of attribute source_of_funds_description.



58
59
60
# File 'lib/unit_openapi_ruby_sdk/models/create_sole_proprietor_thread_application_attributes.rb', line 58

def source_of_funds_description
  @source_of_funds_description
end

#ssnObject

Returns the value of attribute ssn.



18
19
20
# File 'lib/unit_openapi_ruby_sdk/models/create_sole_proprietor_thread_application_attributes.rb', line 18

def ssn
  @ssn
end

#state_of_incorporationObject

Returns the value of attribute state_of_incorporation.



64
65
66
# File 'lib/unit_openapi_ruby_sdk/models/create_sole_proprietor_thread_application_attributes.rb', line 64

def state_of_incorporation
  @state_of_incorporation
end

#tagsObject

Returns the value of attribute tags.



46
47
48
# File 'lib/unit_openapi_ruby_sdk/models/create_sole_proprietor_thread_application_attributes.rb', line 46

def tags
  @tags
end

#transaction_volumeObject

Returns the value of attribute transaction_volume.



72
73
74
# File 'lib/unit_openapi_ruby_sdk/models/create_sole_proprietor_thread_application_attributes.rb', line 72

def transaction_volume
  @transaction_volume
end

#transaction_volume_descriptionObject

Returns the value of attribute transaction_volume_description.



74
75
76
# File 'lib/unit_openapi_ruby_sdk/models/create_sole_proprietor_thread_application_attributes.rb', line 74

def transaction_volume_description
  @transaction_volume_description
end

#us_nexusObject

Returns the value of attribute us_nexus.



70
71
72
# File 'lib/unit_openapi_ruby_sdk/models/create_sole_proprietor_thread_application_attributes.rb', line 70

def us_nexus
  @us_nexus
end

#websiteObject

Returns the value of attribute website.



42
43
44
# File 'lib/unit_openapi_ruby_sdk/models/create_sole_proprietor_thread_application_attributes.rb', line 42

def website
  @website
end

#year_of_incorporationObject

Returns the value of attribute year_of_incorporation.



66
67
68
# File 'lib/unit_openapi_ruby_sdk/models/create_sole_proprietor_thread_application_attributes.rb', line 66

def year_of_incorporation
  @year_of_incorporation
end

Class Method Details

._deserialize(type, value) ⇒ Object

Deserializes the data based on type

Parameters:

  • string

    type Data type

  • string

    value Value to be deserialized

Returns:

  • (Object)

    Deserialized data



669
670
671
672
673
674
675
676
677
678
679
680
681
682
683
684
685
686
687
688
689
690
691
692
693
694
695
696
697
698
699
700
701
702
703
704
705
706
# File 'lib/unit_openapi_ruby_sdk/models/create_sole_proprietor_thread_application_attributes.rb', line 669

def self._deserialize(type, value)
  case type.to_sym
  when :Time
    Time.parse(value)
  when :Date
    Date.parse(value)
  when :String
    value.to_s
  when :Integer
    value.to_i
  when :Float
    value.to_f
  when :Boolean
    if value.to_s =~ /\A(true|t|yes|y|1)\z/i
      true
    else
      false
    end
  when :Object
    # generic object (usually a Hash), return directly
    value
  when /\AArray<(?<inner_type>.+)>\z/
    inner_type = Regexp.last_match[:inner_type]
    value.map { |v| _deserialize(inner_type, v) }
  when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/
    k_type = Regexp.last_match[:k_type]
    v_type = Regexp.last_match[:v_type]
    {}.tap do |hash|
      value.each do |k, v|
        hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
      end
    end
  else # model
    # models (e.g. Pet) or oneOf
    klass = UnitOpenapiRubySdk.const_get(type)
    klass.respond_to?(:openapi_any_of) || klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value)
  end
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



143
144
145
# File 'lib/unit_openapi_ruby_sdk/models/create_sole_proprietor_thread_application_attributes.rb', line 143

def self.acceptable_attributes
  attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
# File 'lib/unit_openapi_ruby_sdk/models/create_sole_proprietor_thread_application_attributes.rb', line 105

def self.attribute_map
  {
    :'ssn' => :'ssn',
    :'passport' => :'passport',
    :'nationality' => :'nationality',
    :'full_name' => :'fullName',
    :'date_of_birth' => :'dateOfBirth',
    :'address' => :'address',
    :'phone' => :'phone',
    :'email' => :'email',
    :'sole_proprietorship' => :'soleProprietorship',
    :'ein' => :'ein',
    :'dba' => :'dba',
    :'evaluation_params' => :'evaluationParams',
    :'website' => :'website',
    :'ip' => :'ip',
    :'tags' => :'tags',
    :'idempotency_key' => :'idempotencyKey',
    :'device_fingerprints' => :'deviceFingerprints',
    :'jwt_subject' => :'jwtSubject',
    :'banks' => :'banks',
    :'source_of_funds' => :'sourceOfFunds',
    :'source_of_funds_description' => :'sourceOfFundsDescription',
    :'business_industry' => :'businessIndustry',
    :'is_incorporated' => :'isIncorporated',
    :'state_of_incorporation' => :'stateOfIncorporation',
    :'year_of_incorporation' => :'yearOfIncorporation',
    :'countries_of_operation' => :'countriesOfOperation',
    :'us_nexus' => :'usNexus',
    :'transaction_volume' => :'transactionVolume',
    :'transaction_volume_description' => :'transactionVolumeDescription',
    :'account_purpose' => :'accountPurpose',
    :'account_purpose_detail' => :'accountPurposeDetail',
    :'business_description' => :'businessDescription'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



645
646
647
648
649
650
651
652
653
654
655
656
657
658
659
660
661
662
663
# File 'lib/unit_openapi_ruby_sdk/models/create_sole_proprietor_thread_application_attributes.rb', line 645

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



186
187
188
189
190
191
# File 'lib/unit_openapi_ruby_sdk/models/create_sole_proprietor_thread_application_attributes.rb', line 186

def self.openapi_nullable
  Set.new([
    :'jwt_subject',
    :'banks',
  ])
end

.openapi_typesObject

Attribute type mapping.



148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
# File 'lib/unit_openapi_ruby_sdk/models/create_sole_proprietor_thread_application_attributes.rb', line 148

def self.openapi_types
  {
    :'ssn' => :'String',
    :'passport' => :'String',
    :'nationality' => :'String',
    :'full_name' => :'FullName',
    :'date_of_birth' => :'Date',
    :'address' => :'Address',
    :'phone' => :'Phone',
    :'email' => :'String',
    :'sole_proprietorship' => :'Boolean',
    :'ein' => :'String',
    :'dba' => :'String',
    :'evaluation_params' => :'EvaluationParams',
    :'website' => :'String',
    :'ip' => :'String',
    :'tags' => :'Hash<String, String>',
    :'idempotency_key' => :'String',
    :'device_fingerprints' => :'Array<DeviceFingerprint>',
    :'jwt_subject' => :'String',
    :'banks' => :'Array<String>',
    :'source_of_funds' => :'ThreadBusinessSourceOfFunds',
    :'source_of_funds_description' => :'String',
    :'business_industry' => :'ThreadBusinessIndustry',
    :'is_incorporated' => :'Boolean',
    :'state_of_incorporation' => :'String',
    :'year_of_incorporation' => :'String',
    :'countries_of_operation' => :'Array<String>',
    :'us_nexus' => :'Array<ThreadBusinessUsNexus>',
    :'transaction_volume' => :'ThreadSoleProprietorshipTransactionVolume',
    :'transaction_volume_description' => :'String',
    :'account_purpose' => :'ThreadBusinessAccountPurpose',
    :'account_purpose_detail' => :'String',
    :'business_description' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



593
594
595
596
597
598
599
600
601
602
603
604
605
606
607
608
609
610
611
612
613
614
615
616
617
618
619
620
621
622
623
624
625
626
627
628
# File 'lib/unit_openapi_ruby_sdk/models/create_sole_proprietor_thread_application_attributes.rb', line 593

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      ssn == o.ssn &&
      passport == o.passport &&
      nationality == o.nationality &&
      full_name == o.full_name &&
      date_of_birth == o.date_of_birth &&
      address == o.address &&
      phone == o.phone &&
      email == o.email &&
      sole_proprietorship == o.sole_proprietorship &&
      ein == o.ein &&
      dba == o.dba &&
      evaluation_params == o.evaluation_params &&
      website == o.website &&
      ip == o.ip &&
      tags == o.tags &&
      idempotency_key == o.idempotency_key &&
      device_fingerprints == o.device_fingerprints &&
      jwt_subject == o.jwt_subject &&
      banks == o.banks &&
      source_of_funds == o.source_of_funds &&
      source_of_funds_description == o.source_of_funds_description &&
      business_industry == o.business_industry &&
      is_incorporated == o.is_incorporated &&
      state_of_incorporation == o.state_of_incorporation &&
      year_of_incorporation == o.year_of_incorporation &&
      countries_of_operation == o.countries_of_operation &&
      us_nexus == o.us_nexus &&
      transaction_volume == o.transaction_volume &&
      transaction_volume_description == o.transaction_volume_description &&
       == o. &&
       == o. &&
      business_description == o.business_description
end

#_to_hash(value) ⇒ Hash

Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value

Parameters:

  • value (Object)

    Any valid value

Returns:

  • (Hash)

    Returns the value in the form of hash



740
741
742
743
744
745
746
747
748
749
750
751
752
# File 'lib/unit_openapi_ruby_sdk/models/create_sole_proprietor_thread_application_attributes.rb', line 740

def _to_hash(value)
  if value.is_a?(Array)
    value.compact.map { |v| _to_hash(v) }
  elsif value.is_a?(Hash)
    {}.tap do |hash|
      value.each { |k, v| hash[k] = _to_hash(v) }
    end
  elsif value.respond_to? :to_hash
    value.to_hash
  else
    value
  end
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


632
633
634
# File 'lib/unit_openapi_ruby_sdk/models/create_sole_proprietor_thread_application_attributes.rb', line 632

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



638
639
640
# File 'lib/unit_openapi_ruby_sdk/models/create_sole_proprietor_thread_application_attributes.rb', line 638

def hash
  [ssn, passport, nationality, full_name, date_of_birth, address, phone, email, sole_proprietorship, ein, dba, evaluation_params, website, ip, tags, idempotency_key, device_fingerprints, jwt_subject, banks, source_of_funds, source_of_funds_description, business_industry, is_incorporated, state_of_incorporation, year_of_incorporation, countries_of_operation, us_nexus, transaction_volume, transaction_volume_description, , , business_description].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



369
370
371
372
373
374
375
376
377
378
379
380
381
382
383
384
385
386
387
388
389
390
391
392
393
394
395
396
397
398
399
400
401
402
403
404
405
406
407
408
409
410
411
412
413
414
415
416
417
418
419
420
421
422
423
424
425
426
427
428
429
430
431
432
433
434
435
436
437
438
439
440
441
442
443
444
445
# File 'lib/unit_openapi_ruby_sdk/models/create_sole_proprietor_thread_application_attributes.rb', line 369

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  pattern = Regexp.new(/^\d{9}$/)
  if !@ssn.nil? && @ssn !~ pattern
    invalid_properties.push("invalid value for \"ssn\", must conform to the pattern #{pattern}.")
  end

  pattern = Regexp.new(/^(A(D|E|F|G|I|L|M|N|O|R|S|T|Q|U|W|X|Z)|B(A|B|D|E|F|G|H|I|J|L|M|N|O|Q|R|S|T|V|W|Y|Z)|C(A|C|D|F|G|H|I|K|L|M|N|O|R|U|V|W|X|Y|Z)|D(E|J|K|M|O|Z)|E(C|E|G|H|R|S|T)|F(I|J|K|M|O|R)|G(A|B|D|E|F|G|H|I|L|M|N|P|Q|R|S|T|U|W|Y)|H(K|M|N|R|T|U)|I(D|E|Q|L|M|N|O|R|S|T)|J(E|M|O|P)|K(E|G|H|I|M|N|P|R|W|Y|Z)|L(A|B|C|I|K|R|S|T|U|V|Y)|M(A|C|D|E|F|G|H|K|L|M|N|O|Q|P|R|S|T|U|V|W|X|Y|Z)|N(A|C|E|F|G|I|L|O|P|R|U|Z)|OM|P(A|E|F|G|H|K|L|M|N|R|S|T|W|Y)|QA|R(E|O|S|U|W)|S(A|B|C|D|E|G|H|I|J|K|L|M|N|O|R|T|V|X|Y|Z)|T(C|D|F|G|H|J|K|L|M|N|O|R|T|V|W|Z)|U(A|G|M|S|Y|Z)|V(A|C|E|G|I|N|U)|W(F|S)|XK|Y(E|T)|Z(A|M|W))$/)
  if !@nationality.nil? && @nationality !~ pattern
    invalid_properties.push("invalid value for \"nationality\", must conform to the pattern #{pattern}.")
  end

  if @full_name.nil?
    invalid_properties.push('invalid value for "full_name", full_name cannot be nil.')
  end

  if @date_of_birth.nil?
    invalid_properties.push('invalid value for "date_of_birth", date_of_birth cannot be nil.')
  end

  if @address.nil?
    invalid_properties.push('invalid value for "address", address cannot be nil.')
  end

  if @phone.nil?
    invalid_properties.push('invalid value for "phone", phone cannot be nil.')
  end

  if @email.nil?
    invalid_properties.push('invalid value for "email", email cannot be nil.')
  end

  pattern = Regexp.new(/^\d{9}$/)
  if !@ein.nil? && @ein !~ pattern
    invalid_properties.push("invalid value for \"ein\", must conform to the pattern #{pattern}.")
  end

  if !@tags.nil? && @tags.length > 15
    invalid_properties.push('invalid value for "tags", number of items must be less than or equal to 15.')
  end

  if !@idempotency_key.nil? && @idempotency_key.to_s.length > 255
    invalid_properties.push('invalid value for "idempotency_key", the character length must be smaller than or equal to 255.')
  end

  if !@idempotency_key.nil? && @idempotency_key.to_s.length < 1
    invalid_properties.push('invalid value for "idempotency_key", the character length must be great than or equal to 1.')
  end

  if !@device_fingerprints.nil? && @device_fingerprints.length > 1
    invalid_properties.push('invalid value for "device_fingerprints", number of items must be less than or equal to 1.')
  end

  if @source_of_funds.nil?
    invalid_properties.push('invalid value for "source_of_funds", source_of_funds cannot be nil.')
  end

  pattern = Regexp.new(/^\d{4}$/)
  if !@year_of_incorporation.nil? && @year_of_incorporation !~ pattern
    invalid_properties.push("invalid value for \"year_of_incorporation\", must conform to the pattern #{pattern}.")
  end

  if !@countries_of_operation.nil? && @countries_of_operation.length < 1
    invalid_properties.push('invalid value for "countries_of_operation", number of items must be greater than or equal to 1.')
  end

  if @transaction_volume.nil?
    invalid_properties.push('invalid value for "transaction_volume", transaction_volume cannot be nil.')
  end

  if @account_purpose.nil?
    invalid_properties.push('invalid value for "account_purpose", account_purpose cannot be nil.')
  end

  invalid_properties
end

#to_bodyHash

to_body is an alias to to_hash (backward compatibility)

Returns:

  • (Hash)

    Returns the object in the form of hash



716
717
718
# File 'lib/unit_openapi_ruby_sdk/models/create_sole_proprietor_thread_application_attributes.rb', line 716

def to_body
  to_hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



722
723
724
725
726
727
728
729
730
731
732
733
734
# File 'lib/unit_openapi_ruby_sdk/models/create_sole_proprietor_thread_application_attributes.rb', line 722

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



710
711
712
# File 'lib/unit_openapi_ruby_sdk/models/create_sole_proprietor_thread_application_attributes.rb', line 710

def to_s
  to_hash.to_s
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



449
450
451
452
453
454
455
456
457
458
459
460
461
462
463
464
465
466
467
468
469
# File 'lib/unit_openapi_ruby_sdk/models/create_sole_proprietor_thread_application_attributes.rb', line 449

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if !@ssn.nil? && @ssn !~ Regexp.new(/^\d{9}$/)
  return false if !@nationality.nil? && @nationality !~ Regexp.new(/^(A(D|E|F|G|I|L|M|N|O|R|S|T|Q|U|W|X|Z)|B(A|B|D|E|F|G|H|I|J|L|M|N|O|Q|R|S|T|V|W|Y|Z)|C(A|C|D|F|G|H|I|K|L|M|N|O|R|U|V|W|X|Y|Z)|D(E|J|K|M|O|Z)|E(C|E|G|H|R|S|T)|F(I|J|K|M|O|R)|G(A|B|D|E|F|G|H|I|L|M|N|P|Q|R|S|T|U|W|Y)|H(K|M|N|R|T|U)|I(D|E|Q|L|M|N|O|R|S|T)|J(E|M|O|P)|K(E|G|H|I|M|N|P|R|W|Y|Z)|L(A|B|C|I|K|R|S|T|U|V|Y)|M(A|C|D|E|F|G|H|K|L|M|N|O|Q|P|R|S|T|U|V|W|X|Y|Z)|N(A|C|E|F|G|I|L|O|P|R|U|Z)|OM|P(A|E|F|G|H|K|L|M|N|R|S|T|W|Y)|QA|R(E|O|S|U|W)|S(A|B|C|D|E|G|H|I|J|K|L|M|N|O|R|T|V|X|Y|Z)|T(C|D|F|G|H|J|K|L|M|N|O|R|T|V|W|Z)|U(A|G|M|S|Y|Z)|V(A|C|E|G|I|N|U)|W(F|S)|XK|Y(E|T)|Z(A|M|W))$/)
  return false if @full_name.nil?
  return false if @date_of_birth.nil?
  return false if @address.nil?
  return false if @phone.nil?
  return false if @email.nil?
  return false if !@ein.nil? && @ein !~ Regexp.new(/^\d{9}$/)
  return false if !@tags.nil? && @tags.length > 15
  return false if !@idempotency_key.nil? && @idempotency_key.to_s.length > 255
  return false if !@idempotency_key.nil? && @idempotency_key.to_s.length < 1
  return false if !@device_fingerprints.nil? && @device_fingerprints.length > 1
  return false if @source_of_funds.nil?
  return false if !@year_of_incorporation.nil? && @year_of_incorporation !~ Regexp.new(/^\d{4}$/)
  return false if !@countries_of_operation.nil? && @countries_of_operation.length < 1
  return false if @transaction_volume.nil?
  return false if @account_purpose.nil?
  true
end